@@ -327,8 +327,7 @@ class PaymentsApi(BaseApi):
         return _result
 
     def complete_payment(self,
-                         payment_id,
-                         body):
+                         payment_id):
         """Does a POST request to /v2/payments/{payment_id}/complete.
 
         Completes (captures) a payment.
@@ -344,9 +343,6 @@ class PaymentsApi(BaseApi):
         Args:
             payment_id (string): Unique ID identifying the payment to be
                 completed.
-            body (object): An object containing the fields to POST for the
-                request.  See the corresponding object definition for field
-                details.
 
         Returns:
             CompletePaymentResponse: Response from the API. Success
@@ -370,12 +366,11 @@ class PaymentsApi(BaseApi):
 
         # Prepare headers
         _headers = {
-            'accept': 'application/json',
-            'content-type': 'application/json; charset=utf-8'
+            'accept': 'application/json'
         }
 
         # Prepare and execute request
-        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
+        _request = self.config.http_client.post(_query_url, headers=_headers)
         OAuth2.apply(self.config, _request)
         _response = self.execute_request(_request)
 
