@@ -24,17 +24,6 @@ class TransactionsApi(BaseApi):
         """Does a GET request to /v2/locations/{location_id}/refunds.
 
         Lists refunds for one of a business's locations.
-        Deprecated - recommend using
-        [SearchOrders](#endpoint-orders-searchorders)
-        ---
-        - __Deprecation date__: 2019-08-15
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/build-basics/api-lifecycle#
-        deprecated): 2021-09-01
-        - [Migration
-        guide](https://developer.squareup.com/docs/payments-api/migrate-from-tr
-        ansactions-api)
-        ---
         In addition to full or partial tender refunds processed through Square
         APIs,
         refunds may result from itemized returns or exchanges through
@@ -122,17 +111,6 @@ class TransactionsApi(BaseApi):
         """Does a GET request to /v2/locations/{location_id}/transactions.
 
         Lists transactions for a particular location.
-        Deprecated - recommend using
-        [SearchOrders](#endpoint-orders-searchorders)
-        ---
-        - __Deprecation date__: 2019-08-15
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/build-basics/api-lifecycle#
-        deprecated): 2021-09-01
-        - [Migration
-        guide](https://developer.squareup.com/docs/payments-api/migrate-from-tr
-        ansactions-api)
-        ---
         Transactions include payment information from sales and exchanges and
         refund
         information from returns and exchanges.
@@ -214,17 +192,6 @@ class TransactionsApi(BaseApi):
 
         Charges a card represented by a card nonce or a customer's card on
         file.
-        Deprecated - recommend using
-        [CreatePayment](#endpoint-payments-createpayment)
-        ---
-        - __Deprecation date__: 2019-08-15
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/build-basics/api-lifecycle#
-        deprecated): 2021-09-01
-        - [Migration
-        guide](https://developer.squareup.com/docs/payments-api/migrate-from-tr
-        ansactions-api)
-        ---
         Your request to this endpoint must include _either_:
         - A value for the `card_nonce` parameter (to charge a card nonce
         generated
@@ -299,17 +266,6 @@ class TransactionsApi(BaseApi):
         """Does a GET request to /v2/locations/{location_id}/transactions/{transaction_id}.
 
         Retrieves details for a single transaction.
-        Deprecated - recommend using
-        [BatchRetrieveOrders](#endpoint-batchretrieveorders)
-        ---
-        - __Deprecation date__: 2019-08-15
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/build-basics/api-lifecycle#
-        deprecated): 2021-09-01
-        - [Migration
-        guide](https://developer.squareup.com/docs/payments-api/migrate-from-tr
-        ansactions-api)
-        ---
 
         Args:
             location_id (string): The ID of the transaction's associated
@@ -364,15 +320,6 @@ class TransactionsApi(BaseApi):
         Captures a transaction that was created with the
         [Charge](#endpoint-charge)
         endpoint with a `delay_capture` value of `true`.
-        ---
-        - __Deprecation date__: 2019-08-15
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/build-basics/api-lifecycle#
-        deprecated): 2021-09-01
-        - [Migration
-        guide](https://developer.squareup.com/docs/payments-api/migrate-from-tr
-        ansactions-api)
-        ---
         See [Delayed capture
         transactions](https://developer.squareup.com/docs/payments/transactions
         /overview#delayed-capture)
@@ -429,17 +376,6 @@ class TransactionsApi(BaseApi):
         """Does a POST request to /v2/locations/{location_id}/transactions/{transaction_id}/refund.
 
         Initiates a refund for a previously charged tender.
-        Deprecated - recommend using
-        [RefundPayment](#endpoint-refunds-refundpayment)
-        ---
-        - __Deprecation date__: 2019-08-15
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/build-basics/api-lifecycle#
-        deprecated): 2021-09-01
-        - [Migration
-        guide](https://developer.squareup.com/docs/payments-api/migrate-from-tr
-        ansactions-api)
-        ---
         You must issue a refund within 120 days of the associated payment.
         See
         [this article](https://squareup.com/help/us/en/article/5060) for more
@@ -507,15 +443,6 @@ class TransactionsApi(BaseApi):
         Cancels a transaction that was created with the
         [Charge](#endpoint-charge)
         endpoint with a `delay_capture` value of `true`.
-        ---
-        - __Deprecation date__: 2019-08-15
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/build-basics/api-lifecycle#
-        deprecated): 2021-09-01
-        - [Migration
-        guide](https://developer.squareup.com/docs/payments-api/migrate-from-tr
-        ansactions-api)
-        ---
         See [Delayed capture
         transactions](https://developer.squareup.com/docs/payments/transactions
         /overview#delayed-capture)
