@@ -496,22 +496,13 @@ class V1EmployeesApi(BaseApi):
                        end_clockout_time=None,
                        begin_updated_at=None,
                        end_updated_at=None,
-                       deleted=None,
+                       deleted=False,
                        limit=None,
                        batch_token=None):
         """Does a GET request to /v1/me/timecards.
 
         Provides summary information for all of a business's employee
         timecards.
-        ---
-        - __Deprecation date__: 2020-02-26
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/docs/build-basics/api-lifec
-        ycle#deprecated): 2021-02-26
-        - [Migration
-        guide](https://developer.squareup.com/docs/docs/migrate-from-v1/guides/
-        v1-timecards)
-        ---
 
         Args:
             order (SortOrder, optional): The order in which timecards are
@@ -608,15 +599,6 @@ class V1EmployeesApi(BaseApi):
         `API_CREATE` event and a `clockin_time` set to the current time
         unless
         the request provides a different value.
-        ---
-        - __Deprecation date__: 2020-02-26
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/docs/build-basics/api-lifec
-        ycle#deprecated): 2021-02-26
-        - [Migration
-        guide](https://developer.squareup.com/docs/docs/migrate-from-v1/guides/
-        v1-timecards)
-        ---
         To import timecards from another
         system (rather than clocking someone in). Specify the `clockin_time`
         and* `clockout_time` in the request.
@@ -678,26 +660,15 @@ class V1EmployeesApi(BaseApi):
         Connect API endpoints, but cannot be modified. The `deleted` field of
         the `Timecard` object indicates whether the timecard has been
         deleted.
-        ---
-        - __Deprecation date__: 2020-02-26
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/docs/build-basics/api-lifec
-        ycle#deprecated): 2021-02-26
-        - [Migration
-        guide](https://developer.squareup.com/docs/docs/migrate-from-v1/guides/
-        v1-timecards)
-        ---
-        *Note**: By default, deleted timecards appear alongside valid
+        __Note__: By default, deleted timecards appear alongside valid
         timecards in
         results returned by the
         [ListTimecards](#endpoint-v1employees-listtimecards)
         endpoint. To filter deleted timecards, include the `deleted` query
         parameter in the list request.
-        <aside>
         Only approved accounts can manage their employees with Square.
         Unapproved accounts cannot use employee management features with the
         API.
-        </aside>
 
         Args:
             timecard_id (string): The ID of the timecard to delete.
@@ -741,15 +712,6 @@ class V1EmployeesApi(BaseApi):
         """Does a GET request to /v1/me/timecards/{timecard_id}.
 
         Provides the details for a single timecard.
-        ---
-        - __Deprecation date__: 2020-02-26
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/docs/build-basics/api-lifec
-        ycle#deprecated): 2021-02-26
-        - [Migration
-        guide](https://developer.squareup.com/docs/docs/migrate-from-v1/guides/
-        v1-timecards)
-        ---
         <aside>
         Only approved accounts can manage their employees with Square.
         Unapproved accounts cannot use employee management features with the
@@ -806,15 +768,6 @@ class V1EmployeesApi(BaseApi):
         Modifies the details of a timecard with an `API_EDIT` event for
         the timecard. Updating an active timecard with a `clockout_time`
         clocks the employee out.
-        ---
-        - __Deprecation date__: 2020-02-26
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/docs/build-basics/api-lifec
-        ycle#deprecated): 2021-02-26
-        - [Migration
-        guide](https://developer.squareup.com/docs/docs/migrate-from-v1/guides/
-        v1-timecards)
-        ---
 
         Args:
             timecard_id (string): TThe ID of the timecard to modify.
@@ -868,15 +821,6 @@ class V1EmployeesApi(BaseApi):
 
         Provides summary information for all events associated with a
         particular timecard.
-        ---
-        - __Deprecation date__: 2020-02-26
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/docs/build-basics/api-lifec
-        ycle#deprecated): 2021-02-26
-        - [Migration
-        guide](https://developer.squareup.com/docs/docs/migrate-from-v1/guides/
-        v1-timecards)
-        ---
         <aside>
         Only approved accounts can manage their employees with Square.
         Unapproved accounts cannot use employee management features with the
@@ -934,15 +878,6 @@ class V1EmployeesApi(BaseApi):
 
         Provides the details for all of a location's cash drawer shifts during
         a date range. The date range you specify cannot exceed 90 days.
-        ---
-        - __Deprecation date__: 2020-02-26
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/docs/build-basics/api-lifec
-        ycle#deprecated): 2021-02-26
-        - [Migration
-        guide](https://developer.squareup.com/docs/docs/migrate-from-v1/guides/
-        v1-cashdrawershifts)
-        ---
 
         Args:
             location_id (string): The ID of the location to list cash drawer
@@ -1012,15 +947,6 @@ class V1EmployeesApi(BaseApi):
 
         Provides the details for a single cash drawer shift, including all
         events that occurred during the shift.
-        ---
-        - __Deprecation date__: 2020-02-26
-        - [__Retirement
-        date__](https://developer.squareup.com/docs/docs/build-basics/api-lifec
-        ycle#deprecated): 2021-02-26
-        - [Migration
-        guide](https://developer.squareup.com/docs/docs/migrate-from-v1/guides/
-        v1-cashdrawershifts)
-        ---
 
         Args:
             location_id (string): The ID of the location to list cash drawer
